#ifndef QUEST_GLOBAL
#define QUEST_GLOBAL

/* debugging, used in:
	-all error reports-
*/
#define VERBOSE_ERRORS		(0)

/* game version, used in:
	init_widgets()
*/
#define QUEST_WINDOW_TITLE 	"gQuest - 0.0.15"

/* game cycle delay time in milliseconds, used in:
	init_widgets()
*/
#define GAME_CYCLE_TIME		(100)

/* map dimensions, used in:
	Map.cell
   MAKE SURE THESE VALUES FIT IN 16 BITS!
*/
#define MAX_MAP_X		(256) 
#define MAX_MAP_Y		(256)

/* graphical variables, used in:
	-nothing yet-
*/
#define TILE_SIZE		(24)
#define XSPACES			(20)
#define YSPACES			(20)

/* array sizes, used in:
	item.sprites
	monster.sprites
	monster.path
	space.sprites
*/
#define ITEM_FRAMES		(13)
#define MONSTER_MEMORY		(8)
#define MONSTER_FRAMES		(6)
#define SPACE_FRAMES		(4)

/* space types, used in:
	Monster.access
	Space.type
*/
#define MOUNTAIN		(0x0001)
#define WATER			(0x0002)
#define GRASS			(0x0004)
#define DIRT			(0x0008)
#define STREET			(0x0010)
#define LAVA			(0x0020)
#define	ICE			(0x0040)
#define SAND			(0x0080)

/* directions, used in:
	Monster.facing
*/
#define UP			(0x0001)
#define UP_RIGHT		(0x0002)
#define RIGHT			(0x0004)
#define DOWN_RIGHT		(0x0008)
#define DOWN			(0x0010)
#define DOWN_LEFT		(0x0020)
#define LEFT			(0x0040)
#define UP_LEFT			(0x0080)

#define NORTH			(0x0001)
#define NORTH_EAST		(0x0002)
#define EAST			(0x0004)
#define SOUTH_EAST		(0x0008)
#define SOUTH			(0x0010)
#define SOUTH_WEST		(0x0020)
#define WEST			(0x0040)
#define NORTH_WEST		(0x0080)

/* pose types, used in:
	Monster.state
*/
#define LEFT_FOOT		(0)
#define RIGHT_FOOT		(1)
#define IDLE_1			(2)
#define IDLE_2			(3)
#define IDLE_3			(4)
#define IDLE_4			(5)

/* quality types, used in:
	Item.state
	-to refer to an animation frame-
*/
#define BROKEN			(0)
#define DAMAGED_1		(1)
#define DAMAGED_2		(2)
#define DAMAGED_3		(3)
#define DAMAGED_4		(4)
#define OK_1			(5)
#define OK_2			(6)
#define OK_3			(7)
#define OK_4			(8)
#define ON_FIRE_1		(9)
#define ON_FIRE_2		(10)
#define ON_FIRE_3		(11)
#define ON_FIRE_4		(12)

/* animation frame names for spaces, used in:
	set_space()
*/
#define FIRST_FRAME		(0)
#define SECOND_FRAME		(1)
#define THIRD_FRAME		(2)
#define FOURTH_FRAME		(3)

/* races, used in:
	Monster.race
*/
#define NEW_MONSTER		(0x0000)
#define	HUMAN			(0x0001)
#define ELF			(0x0002)
#define DWARF			(0x0004)
#define GNOME			(0x0008)
#define ORC			(0x0010)
#define GOBLIN			(0x0020)
#define KOBOLD			(0x0080)
#define OGRE			(0x0100)
#define WILD_ANIMAL		(0x0200)
#define DOMEST_ANIMAL		(0x0400)
#define GOOD_MONSTER		(0x0800)
#define NEUTRAL_MONSTER		(0x1000)
#define EVIL_MONSTER		(0x2000)

/* item kinds, used in:
	Item.kind
*/
#define NEW_ITEM		(0)
#define UNKNOWN_ITEM		(1)
#define RUG			(2)
#define BOULDER			(3)
#define TREE			(4)
#define CAMPFIRE		(5)
#define BARREL			(6)

/* item properties, used in:
	Item.properties
*/
#define IS_MOVABLE		(0x0001)
#define IS_BASHABLE		(0x0002)
#define IS_STACKABLE		(0x0004)
#define IS_FLAMABLE		(0x0008)
#define IS_TREADABLE		(0x0010)
#define IS_PORTABLE		(0x0020)

/* monser properties, used in:
	Monster.properties
*/
#define IS_PLAYER		(0x0001)
#define IS_HOSTILE		(0x0002)
#define IS_SLEEPING		(0x0004)
#define IS_DEAD			(0x0008)
#define IS_DIZZY		(0x0010)
#define IS_INVISIBLE		(0x0020)

/* x and y composition of directions, used in:
	-nothing yet-
*/
#define N_X			(0)
#define NE_X			(1)
#define E_X			(1)
#define SE_X			(1)
#define S_X			(0)
#define SW_X			(-1)
#define W_X			(-1)
#define NW_X			(-1)
#define N_Y			(-1)
#define NE_Y			(-1)
#define E_Y			(0)
#define SE_Y			(1)
#define S_Y			(1)
#define SW_Y			(1)
#define W_Y			(0)
#define NW_Y			(-1)

#define NORTH_X			(0)
#define NORTH_EAST_X		(1)
#define EAST_X			(1)
#define SOUTH_EAST_X		(1)
#define SOUTH_X			(0)
#define SOUTH_WEST_X		(-1)
#define WEST_X			(-1)
#define NORTH_WEST_X		(-1)
#define NORTH_Y			(-1)
#define NORTH_EAST_Y		(-1)
#define EAST_Y			(0)
#define SOUTH_EAST_Y		(1)
#define SOUTH_Y			(1)
#define SOUTH_WEST_Y		(1)
#define WEST_Y			(0)
#define NORTH_WEST_Y		(-1)

/* game control flags, used in:
	GameControl.game_state
*/
#define COMBAT_MODE		(0x0001)
#define TURN_DONE		(0x0002)
#define QUIT_GAME		(0x0004)

/* sprite id's, used in:
	IMAGE()
	PIXMAP()
	MASK()
*/
#define INTRO_SCREEN		(1)
#define QUEST_LOGO		(2)
#define UNKNOWN_SPACE_TYPE	(3)
#define GRASS_1			(4)
#define GRASS_2			(5)
#define DIRT_1			(6)
#define DIRT_2			(7)
#define UNKNOWN_ITEM_ICON	(8)
#define CAMPFIRE_DOUSED		(9)
#define CAMPFIRE_BURNING_1	(10)
#define CAMPFIRE_BURNING_2	(11)
#define CAMPFIRE_BURNING_3	(12)
#define CAMPFIRE_BURNING_4	(13)
#define RUG_1			(14)
#define BOULDER_1		(15)
#define TREE_1			(16)
#define BARREL_1		(17)

/* quick image retriever, used in:
	wherever you need an image
*/
#define SPRITELIST		(gamec->sprites)
#define IMAGE(N)		(((Sprite*) g_list_nth_data(SPRITELIST,N))->image)
#define PIXMAP(N)		(((Sprite*) g_list_nth_data(SPRITELIST,N))->pixmap)
#define MASK(N)			(((Sprite*) g_list_nth_data(SPRITELIST,N))->mask)

/* future functions, used in:
	-wherever you need (gamec->cycle_cnt) + n-
*/
#define CYCLE_CNT		(gamec->cycle_cnt)
#define CYCLE_CNT_MAX		(256)
#define INCR_CYCLE(N)		((CYCLE_CNT+N)%CYCLE_CNT_MAX)

/* mask operators, used in:
	-wherever you set,clr,chk a mask-
*/
#define SET(M,B)		(M | B)
#define CLR(M,B)		(M & ~B)
#define CHK(M,B)		(((M & B) == 0) ? 0 : 1)

/* widgets, used in: 
	init_widgets()
*/
#define MAP_WINDOW		(gamec->map_window->window)
#define MAP_BOX			(gamec->map_window->box)
#define MAP_MENU		(gamec->map_window->menu)
#define MAP_DRAWING_AREA	(gamec->map_window->drawing_area)
#define MAP_AREA		(gamec->map_window->area)
#define MAP_GC			(gamec->map_window->gc)

/* the viewing area's origins, used in:
	make_area()
*/
#define AREA_OX			(gamec->map_window->area_ox)
#define AREA_OY			(gamec->map_window->area_oy)

/* space retrieval, used in:
	-map functions-
*/
#define MAP(X,Y)		(gamec->map->cell[X][Y])

#endif /* QUEST_GLOBAL */
